KeyAttributes

Struct KeyAttributes 

pub struct KeyAttributes {
    pub created_on: Option<DateTime<Utc>>,
    pub enabled: Option<bool>,
    pub expires_on: Option<DateTime<Utc>>,
    pub not_before: Option<DateTime<Utc>>,
    pub recoverable_days: Option<u8>,
    pub recovery_level: Option<String>,
    pub updated_on: Option<DateTime<Utc>>,
}

Fields

created_on: Option<DateTime<Utc>>

Creation time in UTC.

enabled: Option<bool>

Determines whether the object is enabled.

expires_on: Option<DateTime<Utc>>

Expiry date in UTC.

not_before: Option<DateTime<Utc>>

Not before date in UTC.

recoverable_days: Option<u8>

softDelete data retention days. Value should be >=7 and <=90 when softDelete enabled, otherwise 0.

recovery_level: Option<String>

Reflects the deletion recovery level currently in effect for keys in the current vault. If it contains ‘Purgeable’ the key can be permanently deleted by a privileged user; otherwise, only the system can purge the key, at the end of the retention interval.

updated_on: Option<DateTime<Utc>>

Last updated time in UTC.